"""A setuptools based setup module.
See:
https://packaging.python.org/guides/distributing-packages-using-setuptools/
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

# Get the long description from the README file
long_description = (here / "README.md").read_text(encoding="utf-8")

# Arguments marked as "Required" below must be included for upload to PyPI.
# Fields marked as "Optional" may be commented out.

setup(
	# This is the name of your project. The first time you publish this
	# package, this name will be registered for you. It will determine how
	# users can install this project, e.g.:
	#
	# $ pip install sampleproject
	#
	# And where it will live on PyPI: https://pypi.org/project/sampleproject/
	#
	# There are some restrictions on what makes a valid project name
	# specification here:
	# https://packaging.python.org/specifications/core-metadata/#name
	name="ShanCsv",  # Required
	# Versions should comply with PEP 440:
	# https://www.python.org/dev/peps/pep-0440/
	#
	# For a discussion on single-sourcing the version across setup.py and the
	# project code, see
	# https://packaging.python.org/guides/single-sourcing-package-version/
	version="0.5",  # Required
	# This is a one-line description or tagline of what your project does. This
	# corresponds to the "Summary" metadata field:
	# https://packaging.python.org/specifications/core-metadata/#summary
	description="A Python Package for CSV File Parsing and Rendering",  # Optional
	# This is an optional longer description of your project that represents
	# the body of text which users will see when they visit PyPI.
	#
	# Often, this is the same as your README, so you can just read it in from
	# that file directly (as we have already done above)
	#
	# This field corresponds to the "Description" metadata field:
	# https://packaging.python.org/specifications/core-metadata/#description-optional
	long_description=long_description,  # Optional
	# Denotes that our long_description is in Markdown; valid values are
	# text/plain, text/x-rst, and text/markdown
	#
	# Optional if long_description is written in reStructuredText (rst) but
	# required for plain-text or Markdown; if unspecified, "applications should
	# attempt to render [the long_description] as text/x-rst; charset=UTF-8 and
	# fall back to text/plain if it is not valid rst" (see link below)
	#
	# This field corresponds to the "Description-Content-Type" metadata field:
	# https://packaging.python.org/specifications/core-metadata/#description-content-type-optional
	long_description_content_type="text/markdown",  # Optional (see note above)
	# This should be a valid link to your project's main homepage.
	#
	# This field corresponds to the "Home-Page" metadata field:
	# https://packaging.python.org/specifications/core-metadata/#home-page-optional
	url="https://github.com/Ninjago77/ShanCsv",  # Optional
	# This should be your name or the name of the organization which owns the
	# project.
	author="Shanvanth Arunmozhi",  # Optional
	# This should be a valid email address corresponding to the author listed
	# above.
	author_email="shanvantharunmozhi@gmail.com",  # Optional
	# Classifiers help users find your project by categorizing it.
	#
	# For a list of valid classifiers, see https://pypi.org/classifiers/
	classifiers=[  # Optional
		# How mature is this project? Common values are
		#   3 - Alpha
		#   4 - Beta
		#   5 - Production/Stable
		"Development Status :: 3 - Alpha",
		# Indicate who your project is intended for
		"Intended Audience :: Developers",
		"Topic :: Database",
		"Topic :: Software Development :: Libraries :: Python Modules",
		"Topic :: Software Development :: Libraries",
		# Pick your license as you wish
		"License :: OSI Approved :: MIT License",
		# Specify the Python versions you support here. In particular, ensure
		# that you indicate you support Python 3. These classifiers are *not*
		# checked by 'pip install'. See instead 'python_requires' below.
		"Programming Language :: Python :: 3",
		"Programming Language :: Python :: 3.8",
		"Programming Language :: Python :: 3.9",
		"Programming Language :: Python :: 3.10",
		"Programming Language :: Python :: 3.11",
		"Programming Language :: Python :: 3.12",
		"Programming Language :: Python :: 3 :: Only",
	],
	##### Custom #####
	license_files = ("LICENSE.txt",),
	# This field adds keywords for your project which will appear on the
	# project page. What does your project relate to?
	#
	# Note that this is a list of additional keywords, separated
	# by commas, to be used to assist searching for the distribution in a
	# larger catalog.
	keywords="samplecsv, shancsv, csv, comma-sperated-values, data, storage, development",  # Optional
	# When your source code is in a subdirectory under the project root, e.g.
	# `src/`, it is necessary to specify the `package_dir` argument.
	package_dir={"": "src"},  # Optional
	# You can just specify package directories manually here if your project is
	# simple. Or you can use find_packages().
	#
	# Alternatively, if you just want to distribute a single Python file, use
	# the `py_modules` argument instead as follows, which will expect a file
	# called `my_module.py` to exist:
	#
	#   py_modules=["my_module"],
	#
	packages=find_packages(where="src"),  # Required
	# Specify which Python versions you support. In contrast to the
	# 'Programming Language' classifiers above, 'pip install' will check this
	# and refuse to install the project if the version does not match. See
	# https://packaging.python.org/guides/distributing-packages-using-setuptools/#python-requires
	python_requires=">=3.8, <4",
	# This field lists other packages that your project depends on to run.
	# Any package you put here will be installed by pip when your project is
	# installed, so they must be valid existing projects.
	#
	# For an analysis of "install_requires" vs pip's requirements files see:
	# https://packaging.python.org/discussions/install-requires-vs-requirements/
	install_requires=[],  # Optional
	# List additional URLs that are relevant to your project as a dict.
	#
	# This field corresponds to the "Project-URL" metadata fields:
	# https://packaging.python.org/specifications/core-metadata/#project-url-multiple-use
	#
	# Examples listed include a pattern for specifying where the package tracks
	# issues, where the source is hosted, where to say thanks to the package
	# maintainers, and where to support the project financially. The key is
	# what's used to render the link text on PyPI.
	project_urls={  # Optional
		"Bug Reports": "https://github.com/Ninjago77/ShanCsv/issues",
		"Docs": "https://github.com/Ninjago77/ShanCsv#readme",
	},
)